diff graal/GraalCompiler/src/com/sun/c1x/ir/ArrayLength.java @ 2622:91d3952f7eb7

Framestate work : using stateAFter and reducting the number of nodes with framestates. Intermediate state (does not pass tests)
author Gilles Duboscq <gilles.duboscq@oracle.com>
date Tue, 10 May 2011 12:37:46 +0200
parents fec99fc30af1
children 569228710be8
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/ArrayLength.java	Tue May 10 11:55:12 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/ArrayLength.java	Tue May 10 12:37:46 2011 +0200
@@ -42,10 +42,10 @@
     /**
      * Constructs a new ArrayLength instruction.
      * @param array the instruction producing the array
      * @param newFrameState the state before executing this instruction
      */
-    public ArrayLength(Value array, FrameState newFrameState, Graph graph) {
-        super(CiKind.Int, array, newFrameState, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public ArrayLength(Value array, FrameState stateAfter, Graph graph) {
+        super(CiKind.Int, array, stateAfter, INPUT_COUNT, SUCCESSOR_COUNT, graph);
     }
 
     @Override
@@ -42,10 +42,10 @@
      * Constructs a new ArrayLength instruction.
      * @param array the instruction producing the array
-     * @param newFrameState the state before executing this instruction
+     * @param newFrameState the state after executing this instruction
      */